Learn R Programming

clustRcompaR (version 0.2.0)

inaugural_addresses: Data on the inaugural addresses by every United States President (from the quanteda package)

Description

Data on the inaugural addresses by every United States President (from the quanteda package)

Usage

inaugural_addresses

Arguments

Format

Data frame with columns #'

texts

text contents of the inaugural addresses

Year

year of the address

President

last name of the President

FirstName

first name of the President